quickpython
_________________

[![PyPI version](https://badge.fury.io/py/quickpython.svg)](http://badge.fury.io/py/quickpython)
[![Build Status](https://travis-ci.org/timothycrosley/quickpython.svg?branch=master)](https://travis-ci.org/timothycrosley/quickpython)
[![codecov](https://codecov.io/gh/timothycrosley/quickpython/branch/master/graph/badge.svg)](https://codecov.io/gh/timothycrosley/quickpython)
[![Join the chat at https://gitter.im/timothycrosley/quickpython](https://badges.gitter.im/timothycrosley/quickpython.svg)](https://gitter.im/timothycrosley/quickpython?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![License](https://img.shields.io/github/license/mashape/apistatus.svg)](https://pypi.python.org/pypi/quickpython/)
[![Downloads](https://pepy.tech/badge/quickpython)](https://pepy.tech/project/quickpython)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://timothycrosley.github.io/isort/)
_________________

[Read Latest Documentation](https://timothycrosley.github.io/quickpython/) - [Browse GitHub Code Repository](https://github.com/timothycrosley/quickpython/)
_________________

**quickpython** A retro interactive coding environment powered by Python and nostalgia 
